Package: jrSiCKLSNMF
Type: Package
Title: Multimodal Single-Cell Omics Dimensionality Reduction
Version: 1.2.4
Authors@R: 
    c(person("Dorothy","Ellis",email="ddemoreellis@gmail.com",role=c("aut","cre"),
    comment=c(ORCID="0000-0002-8624-0042")),
    person("Susmita","Datta",email="susmita.datta@ufl.edu",role="ths"),
    person("Kenneth","Perkins",role="ctb",
      comment="Util.h function author, http://programmingnotes.org/"),
    person("Renaud","Gaujoux",role="ctb",comment="Author of .nndsvd R adaptation"))
Description: Methods to perform Joint graph Regularized Single-Cell Kullback-Leibler Sparse Non-negative Matrix Factorization ('jrSiCKLSNMF', pronounced "junior sickles NMF") on quality controlled single-cell multimodal omics count data. 'jrSiCKLSNMF' specifically deals with dual-assay scRNA-seq and scATAC-seq data. This package contains functions to extract meaningful latent factors that are shared across omics modalities. These factors enable accurate cell-type clustering and facilitate visualizations. Methods for pre-processing, clustering, and mini-batch updates and other adaptations for larger datasets are also included. For further details on the methods used in this package please see Ellis, Roy, and Datta (2023) <doi:10.3389/fgene.2023.1179439>.
License: GPL-3
Encoding: UTF-8
Imports: Rcpp (>= 1.0.9), igraph, umap, kknn, ggplot2, methods, stats,
        rlang, Matrix,
        data.table,parallel,pbapply,cluster,MASS,clValid,factoextra,
        foreach,irlba,bluster,Rdpack,ggrepel
Suggests: knitr, rmarkdown
LinkingTo: Rcpp, RcppArmadillo, RcppProgress
LazyData: true
LazyDataCompression: xz
VignetteBuilder: knitr
RdMacros: Rdpack
NeedsCompilation: yes
Packaged: 2026-05-15 08:11:04 UTC; dorothy
Author: Dorothy Ellis [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-8624-0042>),
  Susmita Datta [ths],
  Kenneth Perkins [ctb] (Util.h function author,
    http://programmingnotes.org/),
  Renaud Gaujoux [ctb] (Author of .nndsvd R adaptation)
Maintainer: Dorothy Ellis <ddemoreellis@gmail.com>
Depends: R (>= 3.5.0)
Repository: CRAN
Date/Publication: 2026-05-15 12:00:02 UTC
Config/roxygen2/version: 8.0.0
Built: R 4.6.0; aarch64-apple-darwin23; 2026-05-15 13:59:56 UTC; unix
Archs: jrSiCKLSNMF.so.dSYM
