useDynLib(jrSiCKLSNMF, .registration=TRUE)
importFrom("Rcpp","evalCpp")
importFrom("bluster","makeKNNGraph","makeSNNGraph")
importFrom("igraph","laplacian_matrix","cluster_louvain")
importFrom("umap","umap","umap.defaults")
importFrom("kknn","specClust")
import("ggplot2")
import("ggrepel")
importFrom("methods","new","as","is")
importFrom("data.table","copy")
importFrom("stats","runif","kmeans","median")
importFrom("rlang",".data","is_empty")
importFrom("MASS","ginv")
import("Matrix")
import("parallel")
import("foreach")
import("pbapply")
import("rlang")
import("cluster")
import("clValid")
import("factoextra")
import("irlba")
importFrom("Rdpack","reprompt")
## export all regularly named functions
## (but allow for private functions whose name starts with a dot).name <- function(...)
exportPattern("^[[:alpha:]]+")

