# jrSiCKLSNMF
This package contains code to run joint graph-regularized single-cell Kullback-Leibler Non-negative Matrix Factorization

To install:
```{r package}
install.packages("devtools")
devtools::install_github("ellisdoro/jrSiCKLSNMF")
```

<!-- badges: start -->
[![R-CMD-check](https://github.com/ellisdoro/jrSiCKLSNMF/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/ellisdoro/jrSiCKLSNMF/actions/workflows/R-CMD-check.yaml)
<!-- badges: end -->

